@@ -27,7 +27,7 @@ gchar*
 conboy_get_request_token_and_auth_link (const gchar *call_url, const gchar *link_url, GError **error);
 
 gboolean
-conboy_get_access_token (const gchar *url, const gchar *verifier);
+conboy_get_access_token (const gchar *url, const gchar *verifier, GError **error);
 
 
 #endif /*CONBOY_OAUTH_H_*/
